@@ -393,8 +393,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "aarch64"
-#define DEFAULT_MACHINE "aarch64"
+#define MACHINE_TYPE "amd64"
+#define DEFAULT_MACHINE "amd64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -529,16 +529,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 5
+#define MYSQL_VERSION_PATCH 7
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.5"
+#define PACKAGE_STRING "MySQL Server 10.6.7"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.5"
-#define VERSION "10.6.5"
+#define PACKAGE_VERSION "10.6.7"
+#define VERSION "10.6.7"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
