@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2016, 2017 MariaDB Corporation
+ Copyright (c) 2016, 2021, MariaDB Corporation.
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -61,6 +61,13 @@
 #endif /* HAVE_OPENSSL11 */
 #endif
 
+#ifdef LIBRESSL_VERSION_NUMBER
+#define EVP_MD_CTX_SIZE			64
+#define EVP_CIPHER_CTX_SIZE             192
+#define EVP_MD_CTX_init(X) do { memset((X), 0, EVP_MD_CTX_SIZE); EVP_MD_CTX_reset(X); } while(0)
+#define EVP_CIPHER_CTX_init(X) do { memset((X), 0, EVP_CIPHER_CTX_SIZE); EVP_CIPHER_CTX_reset(X); } while(0)
+#else
+
 #ifdef HAVE_WOLFSSL
 #define EVP_MD_CTX_SIZE                 sizeof(wc_Md5)
 #endif
@@ -73,19 +80,23 @@
 #define EVP_MD_CTX_SIZE                 sizeof(EVP_MD_CTX)
 #endif
 
-#define OPENSSL_init_ssl(X,Y)           SSL_library_init()
+#ifndef DH_set0_pqg
 #define DH_set0_pqg(D,P,Q,G)            ((D)->p= (P), (D)->g= (G))
+#endif
+
 #define EVP_CIPHER_CTX_buf_noconst(ctx) ((ctx)->buf)
 #define EVP_CIPHER_CTX_encrypting(ctx)  ((ctx)->encrypt)
 #define EVP_CIPHER_CTX_SIZE             sizeof(EVP_CIPHER_CTX)
 
 #ifndef HAVE_WOLFSSL
+#define OPENSSL_init_ssl(X,Y)           SSL_library_init()
 #define EVP_MD_CTX_reset(X) EVP_MD_CTX_cleanup(X)
-#endif
 #define EVP_CIPHER_CTX_reset(X) EVP_CIPHER_CTX_cleanup(X)
 #define X509_get0_notBefore(X) X509_get_notBefore(X)
 #define X509_get0_notAfter(X) X509_get_notAfter(X)
 #endif
+#endif
+#endif
 
 #ifndef TLS1_3_VERSION
 #define SSL_CTX_set_ciphersuites(X,Y) 0
