@@ -44,7 +44,7 @@ public:
 
   void wait(wsrep::unique_lock<wsrep::mutex>& lock)
   {
-    mysql_mutex_t* mutex= static_cast<mysql_mutex_t*>(lock.mutex().native());
+    mysql_mutex_t* mutex= static_cast<mysql_mutex_t*>(lock.mutex()->native());
     mysql_cond_wait(&m_cond, mutex);
   }
 private:
